pub struct ConditionalOrder {
pub order_id: String,
pub relationship: OrderRelationship,
}Expand description
Describes the relationship between linked orders in a group and this order.
Fields
order_id: StringThe id of the linked Order.
relationship: OrderRelationshipThe relationship of a linked order within a group order
to the current returned Order.