ClientBuilderStep

Struct ClientBuilderStep 

pub struct ClientBuilderStep<CurrentStep> { /* private fields */ }
Phantom Type for compile time enforcement on the order of builder steps used.

Implementations

Source

impl ClientBuilderStep<Step1>

pub fn credentials( self, client_id: &str, client_secret: &str, ) -> Result<ClientBuilderStep<Step2>, Error>

Set your client id/key and secret

pub fn testing_url(self, url: &str) -> ClientBuilderStep<Step3>

Set the testing url for the client to use for sending ALL the requests to your test/mock server instead of the default TradeStation API url.

NOTE: This should ONLY be set for testing and mocking purposes. This should NOT be set used with a production Client.

Source

impl ClientBuilderStep<Step2>

pub async fn authorize( self, authorization_code: &str, ) -> Result<ClientBuilderStep<Step3>, Error>

Use your authorization code to get and set auth token

pub fn token(self, token: Token) -> Result<ClientBuilderStep<Step3>, Error>

Set the current Token for the Client to use

Source

impl ClientBuilderStep<Step3>

pub async fn build(self) -> Result<Client, Error>

Finish building into a Client.