pub enum ActivationTriggerKey {
STT,
STTN,
SBA,
SAB,
DTT,
DTTN,
DBA,
DAB,
TTT,
TTTN,
TBA,
TAB,
}Expand description
The different types of activation trigger keys.
Variants
STT
Single Trade Tick, one trade tick must print within your stop price to trigger your stop.
STTN
Single Trade Tick Within NBBO, one trade tick within the National Best Bid or Offer (NBBO) must print within your stop price to trigger your stop.
SBA
Single Bid/Ask Tick
-
Buy/Cover Orders: One Ask tick must print within your stop price to trigger your stop.
-
Sell/Short Orders: One Bid tick must print within your stop price to trigger your stop.
SAB
Single Ask/Bid Tick
-
Buy/Cover Orders: One Bid tick must print within your stop price to trigger your stop.
-
Sell/Short Orders: One Ask tick must print within your stop price to trigger your stop.
DTT
Double Trade Tick, two consecutive trade ticks must print within your stop price to trigger your stop.
DTTN
Double Trade Tick Within NBBO, two consecutive trade ticks within the National Best Bid or Offer (NBBO) must print within your stop price to trigger your stop.
DBA
Double Bid/Ask Tick
-
Buy/Cover Orders: Two consecutive Ask ticks must print within your stop price to trigger your stop.
-
Sell/Short Orders: Two consecutive Bid ticks must print within your stop price to trigger your stop.
DAB
Double Ask/Bid Tick
-
Buy/Cover Orders: Two consecutive Bid ticks must print within your stop price to trigger your stop.
-
Sell/Short Orders: Two consecutive Ask ticks must print within your stop price to trigger your stop.
TTT
Twice Trade Tick, two trade ticks must print within your stop price to trigger your stop.
TTTN
Twice Trade Tick Within NBBO, two trade ticks within the National Best Bid or Offer (NBBO) must print within your stop price to trigger your stop.
TBA
Twice Bid/Ask Tick
-
Buy/Cover Orders: Two Ask ticks must print within your stop price to trigger your stop.
-
Sell/Short Orders: Two Bid ticks must print within your stop price to trigger your stop.
TAB
Twice Ask/Bid Tick
-
Buy/Cover Orders: Two Bid ticks must print within your stop price to trigger your stop.
-
Sell/Short Orders: Two Ask ticks must print within your stop price to trigger your stop.