pub enum AdvancedOrderType {
Normal,
BRK,
OCO,
}Expand description
Different types of advanced order types
Variants
Normal
Normal Order
BRK
Bracket Order, multiple orders ranged in price.
OCO
Order Cancels Other, multiple orders but only one can be filled as the rest cancel when any of the orders is filled.