pub enum TradeAction {
Buy,
Sell,
BuyToCover,
SellShort,
BuyToOpen,
BuyToClose,
SellToOpen,
SellToClose,
}Expand description
The different trade actions that can be sent or received, and conveys the intent of the order.
Variants
Buy
NOTE: Only for Equities and Futures
Sell
NOTE: Only for Equities and Futures
BuyToCover
NOTE: Only for Equities
SellShort
NOTE: Only for Equities
BuyToOpen
NOTE: Only for Options
BuyToClose
NOTE: Only for Options
SellToOpen
NOTE: Only for Options
SellToClose
NOTE: Only for Options