pub struct OrderRequestLeg {
pub quantity: String,
pub symbol: String,
pub trade_action: TradeAction,
}Expand description
A sub component order apart of the overall trade the Order is for.
Fields
quantity: StringThe quantity of the order.
symbol: StringThe symbol used for this leg of the order.
trade_action: TradeActionThe intent of the order.