pub struct ClientBuilderStep<CurrentStep> { /* private fields */ }Expand description
Phantom Type for compile time enforcement on the order of builder steps used.
Implementations
Sourceimpl ClientBuilderStep<Step1>
impl ClientBuilderStep<Step1>
Sourcepub fn credentials(
self,
client_id: &str,
client_secret: &str,
) -> Result<ClientBuilderStep<Step2>, Error>
pub fn credentials( self, client_id: &str, client_secret: &str, ) -> Result<ClientBuilderStep<Step2>, Error>
Set your client id/key and secret
Sourcepub fn testing_url(self, url: &str) -> ClientBuilderStep<Step3>
pub fn testing_url(self, url: &str) -> ClientBuilderStep<Step3>
Set the testing url for the client to use for sending ALL the requests to your test/mock server instead of the default TradeStation API url.
NOTE: This should ONLY be set for testing and
mocking purposes. This should NOT be set used
with a production Client.