pub enum Duration {
Show 13 variants
DAY,
DYP,
GTC,
GCP,
GTD,
GDP,
OPG,
CLO,
IOC,
FOK,
OneMinute,
ThreeMinute,
FiveMinute,
}Expand description
The length of time for which an order will remain valid in the market.
Variants
DAY
Day, valid until the end of the regular trading session.
DYP
Day Plus, valid until the end of the extended trading session.
GTC
Good Till Canceled, valid until the order is canceled.
NOTE: There is a maximum lifespan of 90 calendar days.
GCP
Good till Canceled Plus, valid until the order is canceled.
NOTE: There is a maximum lifespan of 90 calendar days.
GTD
Good Through Date, valid until a specified date.
NOTE: There is a maximum lifespan of 90 calendar days.
GDP
Good thourgh Date Plus, valid until a specified date.
NOTE: There is a maximum lifespan of 90 calendar days.
OPG
Opening, only valid for listed stocks at the opening session price.
CLO
Close, orders that target the closing session of an exchange.
IOC
Immediate Or Cancel, filled immediatly or canceled.
NOTE: Partial fills of an order are accepted.
FOK
Fill Or Kill, filled entirely or canceled.
NOTE: Does NOT accept partial fills.
OneMinute
1 Minute, expires after one minute of being placed.
ThreeMinute
3 Minute, expires after three minutes of being placed.
FiveMinute
5 Minute, expires after five minutes of being placed.