pub struct AdvancedOrderOptions {
pub add_liquidity: bool,
pub all_or_none: bool,
pub book_only: bool,
pub discretionary_price: String,
pub market_activation_rules: Vec<MarketActivationRule>,
pub non_display: bool,
pub peg_value: String,
pub show_only_quantity: String,
pub time_activation_rules: Vec<TimeActivationRule>,
pub trailing_stop: TrailingStop,
}Expand description
Advanced options for configuring orders.
Fields
add_liquidity: boolThis option allows you to place orders that will only add liquidity on the route you selected. To place an Add Liquidity order, the user must also select Book Only order type.
NOTE: Only calid for Equities.
all_or_none: boolUse this advanced order feature when you do not want a partial fill. Your order will be filled in its entirety or not at all.
NOTE: Valid for Equities and Options.
book_only: boolThis option restricts the destination you choose in the direct routing from re-routing your order to another destination. This type of order is useful in controlling your execution costs by avoiding fees the Exchanges can charge for rerouting your order to another market center.
NOTE: Only valid for Equities.
discretionary_price: StringYou can use this option to reflect a Bid/Ask at a lower/higher price than you are willing to pay using a specified price increment.
NOTE: Only valid for Limit and StopLimit orders.
NOTE: Only valid for Equities.
market_activation_rules: Vec<MarketActivationRule>Allows you to specify when an order will be placed based on the price action of one or more symbols.
non_display: boolWhen you send a non-display order, it will not be reflected in either the Market Depth display or ECN books.
NOTE: Only valid for Equities.
peg_value: StringThis order type is useful to achieve a fair price in a fast or volatile market.
NOTE: Only valid for Equities.
show_only_quantity: StringHides the true number of shares or contracts intended to be bought or sold.
NOTE: Only valid for Limit and StopLimit order types.
NOTE: Only valid for Equities and Futures.
time_activation_rules: Vec<TimeActivationRule>Allows you to specify a time that an order will be placed.
trailing_stop: TrailingStopTrailing Stop offeset, amount or percent.