OrderConfirmation

Struct OrderConfirmation 

pub struct OrderConfirmation {
Show 16 fields pub route: String, pub time_in_force: OrderTimeInForce, pub account_id: String, pub summary_message: String, pub order_confirm_id: String, pub estimated_price: String, pub estimated_price_display: Option<String>, pub estimated_cost: String, pub estimated_cost_display: Option<String>, pub estimated_commission: String, pub estimated_commission_display: Option<String>, pub debit_credit_estimated_cost: Option<String>, pub debit_credit_estimated_cost_display: Option<String>, pub product_currency: Option<String>, pub account_currency: Option<String>, pub initial_margin_display: Option<String>,
}

Fields

route: String

The route of the order.

NOTE: For Stocks and Options, Route value will default to Intelligent if no value is set.

time_in_force: OrderTimeInForce

Defines the duration or expiration timestamp of an Order.

account_id: String

The ID of the Account the order belongs to.

summary_message: String

A short text summary / description of the order.

order_confirm_id: String

The ID of the order confirm.

estimated_price: String

The estimated price of the order.

estimated_price_display: Option<String>

The estimated display price of the order.

estimated_cost: String

The estimated cost of the order.

estimated_cost_display: Option<String>

The estimated display cost of the order.

estimated_commission: String

The estimated commission cost for the order.

estimated_commission_display: Option<String>

The estimated commission cost display for the order.

debit_credit_estimated_cost: Option<String>

The estimated debit or credit cost of the the order.

NOTE: Debit costs will have a positive cost, and credit costs will have a negative cost.

debit_credit_estimated_cost_display: Option<String>

The estimated debit or credit display cost of the the order.

NOTE: Debit costs will have a positive cost, and credit costs will have a negative cost.

product_currency: Option<String>

The currency the product is based on.

NOTE: Only valid for futures orders.

account_currency: Option<String>

The currency the account is based on.

NOTE: Only valid for futures orders.

initial_margin_display: Option<String>

The initial margin display cost of the order.

NOTE: Only valid for futures orders.